<?php

namespace BotKit\Common;

// Команды бота

use BotKit\Common\Message;
use BotKit\Enums\Platform;
use BotKit\Enums\State;
use BotKit\Keyboards\TermsOfServiceKeyboard;
use BotKit\Attachments\ImageAttachment;

class Commands {

    // Отправка условий использования
    public static function showTermsOfService($e, $u, $driver) {
        $driver->editMessage(
            $e->getMessageID(),
            Message::create("[Условия использования]")
            ->withImage(ImageAttachment::fromUrl('https://images.wallpaperscraft.ru/image/single/pustynia_peski_diuny_1207604_800x1200.jpg'))
        );
    }

    public static function helloWorld($e, $u, $driver) {
        // Проверить: сообщение из чата или от пользователя
        $url = 'https://www.wallpaperflare.com/static/929/413/133/artwork-aenami-abstract-painting-wallpaper.jpg';
        $driver->reply(
            $e,
            Message::create("Привет, я - Техбот. Моя задача - облегчить твою жизнь, но, для начала, мне нужно задать несколько вопросов"),
            false
        );
        $driver->reply(
            $e,
            Message
                ::create("Ознакомься с условиями использования прежде чем использовать мои функции")
                ->withKeyboard(new TermsOfServiceKeyboard()),
            false
        );
        $u->setState(State::Registering);
    }

    // Помощь
    public static function help($e, $u, $driver) {
        $driver->reply($e, Message::create("Помощь по BotKit"));
    }

    // Помощь по теме
    public static function helpTopic($e, $u, $driver, $topic) {
        $driver->reply($e, Message::create("Помощь по ".$topic));
    }

    // Помощь по теме
    public static function fallback($e, $u, $driver) {
        $driver->reply($e, Message::create("FALLBACK"));
    }

    public static function registered($e, $u, $driver) {
        // Проверить: сообщение из чата или от пользователя
        $driver->reply($e, Message::create("REGISTERED"));
    }

    // Функция приветствия пользователя
    public static function greetMember($e, $u, $driver) {
        $username = self::getNick($u, $driver);
        $driver->sendToChat(
            $e->getChat(),
            Message::create("Добро пожаловать в чат, ".$username)
        );
    }

    // Функция прощания с пользователем
    public static function bye($e, $u, $driver) {
        $username = self::getNick($u, $driver);
        echo $username;
        $driver->sendMessage($u, Message::create("Будем скучать, ".$username));
    }

    // Возвращает ник пользователя
    private static function getNick($u, $driver) {
        $username = $driver->getUserNick($u);
        if (empty($username)) {
            return $u->getPlatformID();
        }
        return $username;
    }
}
